@@ -34,21 +34,6 @@ describe('+ writeFileSync()', function () {
     assert.equal(data, '{"name":"JP"}\n')
   })
 
-  describe('> when global spaces is set', function () {
-    it('should write JSON with spacing', function () {
-      var file = path.join(TEST_DIR, 'somefile.json')
-      var obj = {name: 'JP'}
-      jf.spaces = 2
-      jf.writeFileSync(file, obj)
-
-      var data = fs.readFileSync(file, 'utf8')
-      assert.equal(data, '{\n  "name": "JP"\n}\n')
-
-      // restore default
-      jf.spaces = null
-    })
-  })
-
   describe('> when JSON replacer is set', function () {
     it('should replace JSON', function () {
       var file = path.join(TEST_DIR, 'somefile.json')
@@ -78,6 +63,14 @@ describe('+ writeFileSync()', function () {
       var data = fs.readFileSync(file, 'utf8')
       assert.strictEqual(data, JSON.stringify(obj, null, 8) + '\n')
     })
+
+    it('should use EOL override', function () {
+      var file = path.join(TEST_DIR, 'somefile.json')
+      var obj = { name: 'JP' }
+      jf.writeFileSync(file, obj, {spaces: 2, EOL: '***'})
+      var data = fs.readFileSync(file, 'utf8')
+      assert.strictEqual(data, '{***  "name": "JP"***}***')
+    })
   })
 
   describe('> when passing encoding string as options', function () {
