@@ -39,24 +39,6 @@ describe('+ writeFile()', function () {
     })
   })
 
-  describe('> when global spaces is set', function () {
-    it('should write JSON with spacing', function (done) {
-      var file = path.join(TEST_DIR, 'somefile.json')
-      var obj = {name: 'JP'}
-      jf.spaces = 2
-      jf.writeFile(file, obj, function (err) {
-        assert.ifError(err)
-
-        var data = fs.readFileSync(file, 'utf8')
-        assert.equal(data, '{\n  "name": "JP"\n}\n')
-
-        // restore default
-        jf.spaces = null
-        done()
-      })
-    })
-  })
-
   describe('> when JSON replacer is set', function () {
     it('should replace JSON', function (done) {
       var file = path.join(TEST_DIR, 'somefile.json')
@@ -104,6 +86,17 @@ describe('+ writeFile()', function () {
         done()
       })
     })
+
+    it('should use EOL override', function (done) {
+      var file = path.join(TEST_DIR, 'somefile.json')
+      var obj = { name: 'jp' }
+      jf.writeFile(file, obj, {spaces: 2, EOL: '***'}, function (err) {
+        assert.ifError(err)
+        var data = fs.readFileSync(file, 'utf8')
+        assert.strictEqual(data, '{***  "name": "jp"***}***')
+        done()
+      })
+    })
   })
 
   describe('> when passing encoding string as options', function () {
